@@ -9,7 +9,8 @@ gg_plant =
 gg_plant1 = gg_plant
 for (i in seq(0.02, 1, length = 70)) {
   gg_plant1 = gg_plant1 +
-    geom_smooth(se = FALSE, span = i, color = rgb(0.4, i, 0.4))
+    geom_smooth(se = FALSE, span = i, color = rgb(0.4, i, 0.4)) +
+    labs(x = "高度", y = "频数")
 }
 gg_plant2 = gg_plant
 for (i in 1:200) {
@@ -17,6 +18,7 @@ for (i in 1:200) {
   idx = sample(nrow(PlantCounts), 300, TRUE)
   gg_plant2 = gg_plant2 +
     geom_smooth(data = PlantCounts[idx, ], se = FALSE,
-                color = rgb(0, 0, 0, 0.1))
+                color = rgb(0, 0, 0, 0.1)) +
+    labs(x = "高度", y = "频数")
 }
 print(gg_plant1 | gg_plant2)
