@@ -4,7 +4,8 @@ library(ggplot2)
 library(patchwork)
 data(gov.cn.pct, package = "MSG")
 p1 = ggplot(gov.cn.pct) +
-  geom_line(aes(percentage,count))
+  geom_line(aes(percentage,count)) +
+  labs(x = "百分比", y = "频数")
 p2 = p1 + xlim(c(9.9,11.1))
 p3 = ggplot(gov.cn.pct,
              aes(percentage, count, group = round0, color = round0)) +
@@ -14,6 +15,7 @@ p3 = ggplot(gov.cn.pct,
     breaks = 10^(2:6),
     labels = trans_format("log10", math_format(10^.x)),
     minor_breaks = as.vector(sapply(2:10, function(x) x * 10^(2:6))))+
+  labs(x = "百分比", y = "频数", color = "舍入到个位") +
   theme(legend.position = c(0.8, 0.8),
         legend.background = element_blank())
 p4 = ggplot(gov.cn.pct, aes(percentage, count, color = round1)) +
@@ -23,6 +25,7 @@ p4 = ggplot(gov.cn.pct, aes(percentage, count, color = round1)) +
     breaks = 10^(2:6),
     labels = trans_format("log10", math_format(10^.x)),
     minor_breaks = as.vector(sapply(2:10, function(x) x * 10^(2:6))))+
+  labs(x = "百分比", y = "频数", color = "舍入到十分位") +
   theme(legend.position = c(0.8, 0.8),
         legend.background = element_blank())
 print((p1 | p2) / (p3 | p4))
