@@ -3,4 +3,5 @@ data("leukemia", package = "survival")
 library(survival)
 library(survminer)
 leukemia.surv = survfit(Surv(time, status) ~ x, data = aml)
-print(ggsurvplot(leukemia.surv, data = aml, ggtheme = theme_gray()))
+print(ggsurvplot(leukemia.surv, data = aml, ggtheme = theme_gray()) +
+        labs(x = "时间", y = "生存概率"))
